@@ -1,11 +1,13 @@
 package Padre::Plugin::Ecliptic::QuickModuleAccessDialog;
+BEGIN {
+  $Padre::Plugin::Ecliptic::QuickModuleAccessDialog::VERSION = '0.20';
+}
+
+# ABSTRACT: Quick module autocomplete dialog
 
 use warnings;
 use strict;
 
-# package exports and version
-our $VERSION = '0.19';
-
 # module imports
 use Padre::Wx ();
 
@@ -274,18 +276,29 @@ sub _update_matches_list_box {
 	return;
 }
 
-
 1;
 
 __END__
+=pod
+
+=head1 NAME
+
+Padre::Plugin::Ecliptic::QuickModuleAccessDialog - Quick module autocomplete dialog
+
+=head1 VERSION
+
+version 0.20
 
 =head1 AUTHOR
 
-Ahmad M. Zawawi C<< <ahmad.zawawi at gmail.com> >>
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 C<< <ahmad.zawawi at gmail.com> >>
+This software is copyright (c) 2010 by Ahmad M. Zawawi.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
 
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
